<?php

/*------------------------------------------*/
/* WPZOOM: Portfolio Showcase               */
/*------------------------------------------*/

class Wpzoom_Portfolio_Showcase extends WP_Widget {

    protected $defaults = array();

    function __construct() {
        /* Widget settings. */
        $widget_ops = array(
            'classname'   => 'portfolio-showcase',
            'description' => 'Portfolio posts shown as a gallery.'
        );

        /* Widget control settings. */
        $control_ops = array( 'id_base' => 'wpzoom-portfolio-showcase' );

        $this->defaults = array(
            'title'                     => '',
            'category'                  => 0,
            'col_number'                => 3,
            'show_popup'                => true,
            'lightbox_open_thumb'       => false,
            'show_popup_caption'        => false,
            'show_categories'           => true,
            'enable_ajax_items_loading' => true,
            'enable_background_video'   => true,
            'show_count'                => 9,
            'view_all_ajax_loading'     => false,
            'view_all_enabled'          => true,
            'view_all_text'             => 'View All',
            'view_all_link'             => ''
        );

        /* Create the widget. */
        parent::__construct( 'wpzoom-portfolio-showcase', 'WPZOOM: Portfolio Showcase', $widget_ops, $control_ops );

        add_action( 'wp_ajax_nopriv_wpz_get_portfolio_items', array( $this, 'wpz_get_portfolio_items' ) );
        add_action( 'wp_ajax_wpz_get_portfolio_items', array( $this, 'wpz_get_portfolio_items' ) );
        add_action( 'wp_ajax_nopriv_wpz_count_portfolio_items', array( $this, 'wpz_count_portfolio_items' ) );
        add_action( 'wp_ajax_wpz_count_portfolio_items', array( $this, 'wpz_count_portfolio_items' ) );
    }

    function widget( $args, $instance ) {

        $instance = wp_parse_args( (array) $instance, $this->defaults );
        extract( $args );

        /* User-selected settings. */
        $title                     = apply_filters( 'widget_title', $instance['title'] );
        $category                  = $instance['category'];
        $show_count                = $instance['show_count'];
        $col_number                = $instance['col_number'];
        $show_popup                = $instance['show_popup'] == true;
        $lightbox_open_thumb       = $instance['lightbox_open_thumb'] == true;
        $show_popup_caption        = $instance['show_popup_caption'] == true;
        $show_categories           = $instance['show_categories'] == true;
        $background_video          = $instance['enable_background_video'] == true;
        $enable_ajax_items_loading = $instance['enable_ajax_items_loading'] == true;
        $view_all_ajax_loading     = $instance['view_all_ajax_loading'] == true;
        $view_all_enabled          = $instance['view_all_enabled'] == true;
        $view_all_text             = $instance['view_all_text'];
        $view_all_link             = $instance['view_all_link'];

        if (! $view_all_link) {
            $all_link_url = get_page_link( option::get( 'portfolio_url' ) );
        } else {
            $all_link_url      = $view_all_link;
        }

        /* Before widget (defined by themes). */
        echo $before_widget;

        /* Title of widget (before and after defined by themes). */
        if ( $title ) {
            echo $before_title . $title . $after_title;
        }

        $args = array(
            'post_type'      => 'portfolio_item',
            'posts_per_page' => $show_count,
            'orderby' =>'menu_order date'
        );

        if ( $category ) {
            $args['tax_query'] = array(
                array(
                    'taxonomy' => 'portfolio',
                    'terms'    => $category,
                    'field'    => 'term_id',
                )
            );
        }

        $wp_query = new WP_Query( $args );

        $count = $wp_query->found_posts;
        ?>

        <section class="portfolio-archive">

            <?php if ( $wp_query->have_posts() ) : ?>

                <?php if ( $show_categories == true ) { ?>

                    <nav class="portfolio-archive-taxonomies">
                        <ul class="portfolio-taxonomies portfolio-taxonomies-filter-by">
                            <li <?php echo( ! empty( $category ) ? 'data-subcategory="' . $category . '"' : '' ); ?>
                                class="cat-item cat-item-all current-cat" data-counter="<?php echo $count ?>"><a
                                    href="<?php echo get_page_link( option::get( 'portfolio_url' ) ); ?>"><?php _e( 'All', 'wpzoom' ); ?></a>
                            </li>

                            <?php wp_list_categories( array(
                                'title_li'     => '',
                                'hierarchical' => false,
                                'taxonomy'     => 'portfolio',
                                'child_of' => $category
                            ) ); ?>
                        </ul>
                    </nav>

                <?php } ?>

                <div <?php echo( ! empty( $category ) ? 'data-subcategory="' . $category . '"' : '' ); ?>
                    data-ajax-items-loading="<?php echo esc_attr( $enable_ajax_items_loading ) ?>"
                     data-nonce="<?php echo esc_attr( wp_create_nonce( 'wpz_get_portfolio_items' ) ) ?>"
                     data-count-nonce="<?php echo esc_attr( wp_create_nonce( 'wpz_count_portfolio_items' ) ) ?>"
                     data-items-count="<?php echo $count ?>"
                     data-instance="<?php echo esc_attr( wp_json_encode( array(
                         'background_video'   => $background_video,
                         'show_popup'         => $show_popup,
                         'lightbox_open_thumb' => $lightbox_open_thumb,
                         'show_popup_caption' => $show_popup_caption,
                         'show_count'         => $show_count
                     ) ) ) ?>"
                     class="portfolio-grid col_no_<?php echo $col_number; ?>">

                    <?php

                        $this->looper( $wp_query,
                            array(
                                'background_video'   => $background_video,
                                'show_popup'         => $show_popup,
                                'lightbox_open_thumb' => $lightbox_open_thumb,
                                'show_popup_caption' => $show_popup_caption
                            )
                        );

                    ?>

                </div>

            <?php else: ?>

                <div class="inner-wrap">

                    <center>
                        <h3><?php _e('No Portfolio Posts Found', 'wpzoom'); ?></h3>

                        <p class="description"><?php printf( __( 'Please add a few Portfolio Posts first <a href="%1$s">here</a>.', 'wpzoom' ), esc_url( admin_url( 'post-new.php?post_type=portfolio_item' ) ) ); ?></p>

                    </center>

                </div>

            <?php endif; ?>

            <div class="portfolio-preloader">

                <div id="loading-39x">
                    <div class="spinner">
                        <div class="rect1"></div> <div class="rect2"></div> <div class="rect3"></div> <div class="rect4"></div> <div class="rect5"></div>
                    </div>
                </div>
            </div>

            <?php if ( $view_all_enabled ) : ?>

                <div class="portfolio-view_all-link">
                    <a class="btn" href="<?php echo esc_url( $all_link_url ); ?>"
                        <?php if ( ! empty( $view_all_ajax_loading ) ) {
                            echo "data-ajax-loading='1'";
                        } ?>
                       title="<?php echo esc_attr( $view_all_text ); ?>">
                        <?php echo esc_html( $view_all_text ); ?>
                    </a>
                </div><!-- .portfolio-view_all-link -->

            <?php endif; ?>

        </section><!-- .portfolio-archive -->

        <?php
        /* After widget (defined by themes). */
        echo $after_widget;
    }


    function looper( $wp_query, $widget_settings ) {

        $show_popup          = wp_validate_boolean( $widget_settings['show_popup'] );
        $lightbox_open_thumb = wp_validate_boolean( $widget_settings['lightbox_open_thumb'] );
        $show_popup_caption  = wp_validate_boolean( $widget_settings['show_popup_caption'] );
        $background_video    = wp_validate_boolean( $widget_settings['background_video'] );

        while ( $wp_query->have_posts() ) : $wp_query->the_post(); ?><?php

            $portfolios = wp_get_post_terms( get_the_ID(), 'portfolio' );
            $post_thumbnail                    = get_the_post_thumbnail_url( get_the_ID() );
            $portfolio_video_popup_url         = get_post_meta( get_the_ID(), 'wpzoom_portfolio_video_popup_url', true );
            $portfolio_video_popup_url_mp4     = get_post_meta( get_the_ID(), 'wpzoom_portfolio_video_popup_url_mp4', true );
            $portfolio_video_popup_url_webm    = get_post_meta( get_the_ID(), 'wpzoom_portfolio_video_popup_url_webm', true );
            $portfolio_popup_video_type        = get_post_meta( get_the_ID(), 'wpzoom_portfolio_popup_video_type', true );
            $popup_video_type                  = ! empty( $portfolio_popup_video_type ) ? $portfolio_popup_video_type : 'external_hosted';
            $video_background_mp4              = get_post_meta( get_the_ID(), 'wpzoom_portfolio_video_background_mp4', true );
            $video_background_webm             = get_post_meta( get_the_ID(), 'wpzoom_portfolio_video_background_webm', true );

            $is_video_popup_self_hosted     = $portfolio_video_popup_url_mp4 || $portfolio_video_popup_url_webm;
            $popup_self_hosted_src          = ! empty( $portfolio_video_popup_url_mp4 ) ? $portfolio_video_popup_url_mp4 : $portfolio_video_popup_url_webm;
            $has_video_popup = $is_video_popup_self_hosted || (! empty( $portfolio_video_popup_url ));

            $is_video_background_source        = $video_background_mp4 || $video_background_webm;
            $is_video_background               = $background_video && $is_video_background_source;

            $final_background_src     = ! empty( $video_background_mp4 ) ? $video_background_mp4 : $video_background_webm;
            $popup_final_external_src = ! empty( $portfolio_video_popup_url_mp4 ) ? $portfolio_video_popup_url_mp4 : $portfolio_video_popup_url_webm;

            $articleClass = ( ! has_post_thumbnail() && ! $is_video_background ) ? 'no-thumbnail ' : '';

            $size = 'portfolio_item-thumbnail';

            if ( $is_video_background ) {
                $filetype             = wp_check_filetype( $final_background_src );
                $video_atts           = array(
                    'loop',
                    'muted',
                    //'preload="auto"',
                    'poster="' . esc_attr( get_the_post_thumbnail_url( get_the_ID(), $size ) ) . '"'
                );
                $video_atts           = implode( ' ', $video_atts );
                $is_video_popup_class = $is_video_background ? ' is-portfolio-gallery-video-background' : '';
                $articleClass .= $is_video_popup_class;
            }

            if ( is_array( $portfolios ) ) {
                foreach ( $portfolios as $portfolio ) {
                    $articleClass .= ' portfolio_' . $portfolio->term_id . '_item ';
                }
            }

            if ( wp_doing_ajax() ) {
                $articleClass .= ' ' . get_post_type( get_the_ID() );
            }
            ?>
            <article id="post-<?php the_ID(); ?>" <?php post_class( $articleClass ); ?>>

                <?php if ( $popup_video_type === 'self_hosted' && $is_video_popup_self_hosted ): ?>
                    <div id="zoom-popup-<?php echo the_ID(); ?>" class="animated slow mfp-hide"
                         data-src="<?php echo $popup_self_hosted_src; ?>">
                        <div class="mfp-iframe-scaler">
                            <?php
                            echo wp_video_shortcode(
                                array(
                                    'src'  => $popup_self_hosted_src,
                                    'preload' => 'none',
                                    // 'loop' => 'on'
                                    //'autoplay' => 'on'
                                ) );
                            ?>
                            <?php if ( $show_popup_caption ): ?>
                               <div class="mfp-bottom-bar">
                                   <div class="mfp-title">
                                       <a href="<?php echo esc_url( get_permalink() ); ?>"
                                          title="<?php echo esc_attr( get_the_title() ); ?>">
                                           <?php the_title(); ?>
                                       </a>
                                   </div>
                               </div>
                           <?php endif; ?>
                        </div>
                    </div>
                <?php endif;?>

                <a class="reel_video_item" href="<?php echo esc_url( get_permalink() ); ?>" title="<?php echo esc_attr( get_the_title() ); ?>">
                    <?php if($has_video_popup): ?>
                    <div class="entry-thumbnail-popover<?php if ($lightbox_open_thumb) { ?> lightbox_open_full<?php } ?>">
                        <div class="entry-thumbnail-popover-content popover-content--animated data-show-caption="<?php echo $show_popup_caption ?>"">
                            <?php if ( $popup_video_type === 'self_hosted' && $is_video_popup_self_hosted ): ?>
                                <span href="#zoom-popup-<?php echo the_ID(); ?>" class="mfp-inline portfolio-popup-video"></span>
                            <?php elseif ( $popup_video_type === 'external_hosted' && ! empty( $portfolio_video_popup_url ) ): ?>
                                <span class="mfp-iframe portfolio-popup-video"
                                      href="<?php echo $portfolio_video_popup_url; ?>"></span>
                            <?php endif; ?>
                        </div>
                    </div>
                    <?php endif;?>

                    <?php if ( $is_video_background ): ?>
                        <video class="portfolio-gallery-video-background" <?php echo $video_atts ?>>
                            <source src="<?php echo $final_background_src ?>"
                                    type="<?php echo $filetype['type'] ?>">
                        </video>

                        <?php the_post_thumbnail( 'portfolio_item-thumbnail' ); ?>

                    <?php elseif ( has_post_thumbnail() ): ?>

                        <?php the_post_thumbnail( 'portfolio_item-thumbnail' ); ?>

                    <?php else: ?>

                        <img width="600" height="400"
                             src="<?php echo get_template_directory_uri() . '/images/portfolio_item-placeholder.gif'; ?>">

                    <?php endif; ?>

                </a>

                <?php the_title( sprintf( '<h3 class="portfolio_item-title_btm"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h3>' ); ?>


             </article><?php endwhile; ?><?php
    }

    function wpz_get_portfolio_items() {

        ob_start();

        if ( ! wp_verify_nonce( $_POST['nonce'], 'wpz_get_portfolio_items' ) ) {
            wp_send_json_error( array( 'message' => 'Invalid nonce' ) );
        }

        if ( ! empty( $_POST['category_id'] ) && ! empty( $_POST['widget_settings'] ) ) {

            $category_id = sanitize_text_field($_POST['category_id']);

            if(!empty($_POST['show_all'])){
                $show_all = sanitize_text_field($_POST['show_all']);
            }

            $posts_per_page = sanitize_text_field($_POST['widget_settings']['show_count']);

            $args = array(
                'post_type'      => 'portfolio_item',
                'posts_per_page' => empty( $posts_per_page ) ? 9 : $posts_per_page,
                'orderby'        => 'menu_order date',
                'tax_query'      => array(
                    array(
                        'taxonomy'         => 'portfolio',
                        'terms'            => $category_id,
                        'field'            => 'term_id',
                        'include_children' => false
                    )
                )
            );

            if ( ! empty( $show_all ) ) {
                $args['post__not_in'] = explode(',',$_POST['post_not_in']);
            }

            $widget_settings = $_POST['widget_settings'];

            $wp_query = new WP_Query( $args );

            $this->looper( $wp_query, $widget_settings );
            $content = ob_get_clean();
        }

        wp_send_json_success( array(
               'content' => trim( $content ),
               'count'   => $wp_query->found_posts
           ) );
        }

       function wpz_count_portfolio_items() {
           if ( ! wp_verify_nonce( $_POST['nonce'], 'wpz_count_portfolio_items' ) ) {
               wp_send_json_error( array( 'message' => 'Invalid nonce' ) );
           }

           if ( empty( $_POST['category_id'] ) ) {
               wp_send_json_error( array( 'message' => 'Empty category_id from $_POST' ) );
           }
           $category_id = sanitize_text_field( $_POST['category_id'] );
           $args        = array(
               'post_type'      => 'portfolio_item',
               'posts_per_page' => 1,
               'orderby'        => 'menu_order date',
               'tax_query'      => array(
                   array(
                       'taxonomy'         => 'portfolio',
                       'terms'            => $category_id,
                       'field'            => 'term_id',
                       'include_children' => false
                   )
               )
           );

           $wp_query = new WP_Query( $args );

           wp_send_json_success( array(
                   'count' => $wp_query->found_posts
               )
           );
       }


    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;

        /* Strip tags (if needed) and update the widget settings. */
        $instance['title']                     = strip_tags( $new_instance['title'] );
        $instance['category']                  = $new_instance['category'];
        $instance['show_count']                = $new_instance['show_count'];
        $instance['col_number']                = $new_instance['col_number'];
        $instance['show_popup']                = isset( $new_instance['show_popup'] );
        $instance['lightbox_open_thumb']       = isset( $new_instance['lightbox_open_thumb'] );
        $instance['show_popup_caption']        = isset( $new_instance['show_popup_caption'] );
        $instance['show_categories']           = isset( $new_instance['show_categories'] );
        $instance['enable_background_video']   = isset( $new_instance['enable_background_video'] );
        $instance['enable_ajax_items_loading'] = isset( $new_instance['enable_ajax_items_loading'] );
        $instance['view_all_ajax_loading']     = isset( $new_instance['view_all_ajax_loading'] );
        $instance['view_all_enabled']          = isset( $new_instance['view_all_enabled'] );
        $instance['view_all_text']             = $new_instance['view_all_text'];
        $instance['view_all_link']             = $new_instance['view_all_link'];

        return $instance;
    }

    function form( $instance ) {

        $instance = wp_parse_args( (array) $instance, $this->defaults ); ?>

        <h3><?php _e( 'General Settings', 'wpzoom' ); ?></h3>

        <p>
            <label for="<?php echo $this->get_field_id( 'title' ); ?>">Title:</label><br/>
            <input id="<?php echo $this->get_field_id( 'title' ); ?>"
                   name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>"
                   type="text" class="widefat"/>
        </p>

        <p>
            <label for="<?php echo $this->get_field_id( 'category' ); ?>">Category:</label>
            <?php
            $categories = wp_dropdown_categories( array(
                'taxonomy'        => 'portfolio',
                'show_option_all' => 'All',
                'show_count'      => 1,
                'hierarchical'    => 1,
                'selected'        => $instance['category'],
                'name'            => $this->get_field_name( 'category' ),
                'id'              => $this->get_field_id( 'category' )
            ) );
            ?>
        </p>


        <p>
            <label>
                <input class="checkbox" type="checkbox" <?php checked( $instance['show_categories'] ); ?>
                       id="<?php echo $this->get_field_id( 'show_categories' ); ?>"
                       name="<?php echo $this->get_field_name( 'show_categories' ); ?>"/>
                <?php _e( '<strong>Display Category Filter at the Top (Isotope Effect)</strong>', 'wpzoom' ); ?>
                <p class="description"><em><?php _e( 'If you\'ve selected to display posts from <strong>All</strong> categories, then the filter will include top-level portfolio categories (no sub-categories).', 'wpzoom' ); ?></em></p>
                <p class="description"><em><?php _e( 'If you selected to display posts from a specific category, then the filter will display its sub-categories.', 'wpzoom' ); ?></em></p>

            </label>
        </p>

        <hr/>

        <p>
            <label
                for="<?php echo $this->get_field_id( 'show_count' ); ?>"><strong><?php _e( 'Number of Posts', 'wpzoom' ); ?></strong>
                </label>
            <input id="<?php echo $this->get_field_id( 'show_count' ); ?>"
                   name="<?php echo $this->get_field_name( 'show_count' ); ?>"
                   value="<?php echo $instance['show_count']; ?>" type="text" size="2"/>
        </p>



        <p>
            <label>
                <input class="checkbox" type="checkbox" <?php checked( $instance['enable_ajax_items_loading'] ); ?>
                       id="<?php echo $this->get_field_id( 'enable_ajax_items_loading' ); ?>"
                       name="<?php echo $this->get_field_name( 'enable_ajax_items_loading' ); ?>"/>
                <strong><?php _e( 'Load Dynamically New Posts in Each Category', 'wpzoom' ); ?></strong>
                <p class="description"><em><?php _e( 'This option will try to display the same number of posts in each category as it\'s configured in the <strong>Number of Posts</strong> option above.', 'wpzoom' ); ?></em></p>
            </label>
        </p>


        <hr/>

        <h3><?php _e( 'Design & Appearance', 'wpzoom' ); ?></h3>


        <p>
            <label
                for="<?php echo $this->get_field_id( 'col_number' ); ?>"><?php _e( 'Number of Columns', 'wpzoom' ); ?>
                : </label>
            <select id="<?php echo $this->get_field_id( 'col_number' ); ?>"
                    name="<?php echo $this->get_field_name( 'col_number' ); ?>">
                <option value="2" <?php if ( $instance['col_number'] == '2' ) {
                    echo 'selected="selected"';
                } ?>><?php _e( '2', 'wpzoom' ); ?></option>
                <option value="3" <?php if ( $instance['col_number'] == '3' ) {
                    echo 'selected="selected"';
                } ?>><?php _e( '3', 'wpzoom' ); ?></option>
                <option value="4" <?php if ( $instance['col_number'] == '4' ) {
                    echo 'selected="selected"';
                } ?>><?php _e( '4', 'wpzoom' ); ?></option>

            </select>
            <p class="description"><em><?php _e( 'The number of columns may vary depending on screen size', 'wpzoom' ); ?></em></p>
        </p>



        <hr/>

        <h3><?php _e( 'Posts Settings', 'wpzoom' ); ?></h3>

        <p>
            <label>
                <input class="checkbox" type="checkbox" <?php checked( $instance['show_popup'] ); ?>
                       id="<?php echo $this->get_field_id( 'show_popup' ); ?>"
                       name="<?php echo $this->get_field_name( 'show_popup' ); ?>"/>
                <?php _e( 'Enable Lightbox', 'wpzoom' ); ?>
            </label>
        </p>

        <p>
            <label>
                <input class="checkbox" type="checkbox" <?php checked( $instance['lightbox_open_thumb'] ); ?>
                       id="<?php echo $this->get_field_id( 'lightbox_open_thumb' ); ?>"
                       name="<?php echo $this->get_field_name( 'lightbox_open_thumb' ); ?>"/>
                <?php _e( 'Open Lightbox by Clicking Entire Thumbnail', 'wpzoom' ); ?>
            </label>
        </p>

        <p>
            <label>
                <input class="checkbox" type="checkbox" <?php checked( $instance['show_popup_caption'] ); ?>
                       id="<?php echo $this->get_field_id( 'show_popup_caption' ); ?>"
                       name="<?php echo $this->get_field_name( 'show_popup_caption' ); ?>"/>
                <?php _e( 'Show Lightbox Caption', 'wpzoom' ); ?>
            </label>
        </p>

        <p>
            <label>
                <input class="checkbox" type="checkbox" <?php checked( $instance['enable_background_video'] ); ?>
                       id="<?php echo $this->get_field_id( 'enable_background_video' ); ?>"
                       name="<?php echo $this->get_field_name( 'enable_background_video' ); ?>"/>
                <?php _e( 'Enable Background Video on hover', 'wpzoom' ); ?>
            </label>
        </p>



        <hr />

           <h3><?php _e('"View All" or "Load More" Button at the Bottom', 'wpzoom'); ?></h3>

            <p>
                <input class="checkbox" type="checkbox" <?php checked( $instance['view_all_enabled'] ); ?>
                       id="<?php echo $this->get_field_id( 'view_all_enabled' ); ?>"
                       name="<?php echo $this->get_field_name( 'view_all_enabled' ); ?>"/>
                <label
                    for="<?php echo $this->get_field_id( 'view_all_enabled' ); ?>"><?php _e( 'Display View All button', 'wpzoom' ); ?></label>
            </p>

            <p>
                <input class="checkbox" type="checkbox" <?php checked( $instance['view_all_ajax_loading'] ); ?>
                       id="<?php echo $this->get_field_id( 'view_all_ajax_loading' ); ?>"
                       name="<?php echo $this->get_field_name( 'view_all_ajax_loading' ); ?>"/>
                <label
                    for="<?php echo $this->get_field_id( 'view_all_ajax_loading' ); ?>"><strong><?php _e( 'Load new posts dynamically', 'wpzoom' ); ?></strong></label>
            </p>

            <p>
                <label
                    for="<?php echo $this->get_field_id( 'view_all_text' ); ?>"><?php _e( 'Text for View All button', 'wpzoom' ); ?>:</label><br/>
                <input id="<?php echo $this->get_field_id( 'view_all_text' ); ?>"
                       name="<?php echo $this->get_field_name( 'view_all_text' ); ?>"
                       value="<?php echo $instance['view_all_text']; ?>" type="text" class="widefat"/>
               <p class="description"><em><?php _e( 'Change the text to something like <strong>"Load More"</strong> if you have enabled the option to load new posts dynamically.', 'wpzoom' ); ?></em></p>
            </p>

            <p>
                <label
                    for="<?php echo $this->get_field_id( 'view_all_link' ); ?>"><?php _e( 'Link for View All button', 'wpzoom' ); ?>:</label><br/>
                <input id="<?php echo $this->get_field_id( 'view_all_link' ); ?>"
                       name="<?php echo $this->get_field_name( 'view_all_link' ); ?>"
                       value="<?php echo $instance['view_all_link']; ?>" type="text" class="widefat"/>
            </p>

        <?php
    }
}

function wpzoom_register_psc_widget() {
    register_widget( 'Wpzoom_Portfolio_Showcase' );
}

add_action( 'widgets_init', 'wpzoom_register_psc_widget' );